@@ -166,14 +166,17 @@ class Database(object):
         self.open()
 
     def open(self):
-        if self._writable:
-            if self._overwrite:
-                flags = xapian.DB_CREATE_OR_OVERWRITE
+        if isinstance(self.db_path, basestring):
+            if self._writable:
+                if self._overwrite:
+                    flags = xapian.DB_CREATE_OR_OVERWRITE
+                else:
+                    flags = xapian.DB_CREATE_OR_OPEN
+                self.backend = xapian.WritableDatabase(self.db_path, flags)
             else:
-                flags = xapian.DB_CREATE_OR_OPEN
-            self.backend = xapian.WritableDatabase(self.db_path, flags)
-        else:
-            self.backend = xapian.Database(self.db_path)
+                self.backend = xapian.Database(self.db_path)
+        elif isinstance(self.db_path, xapian.Database):
+            self.backend = self.db_path
 
         self.relevance_prefixes = {}
         self.boolean_prefixes = {}
