@@ -88,6 +88,7 @@ class Schema(schema.Form):
         self.database = database
         self.document = xapian.Document()
         self.term_gen = self._init_term_gen(language)
+
         self._handle_children(self)
         return self.document
 
@@ -121,9 +122,12 @@ class Schema(schema.Form):
                 else:
                     raise TypeError("Unknown element %s" % el)
 
-                if el.facet:
-                    self._add_term(el.name, self.facet_prefix, True)
-                handler(el)
+                value = handler(el)
+
+                if value is not None:
+                    if el.facet:
+                        self._add_term(el.name, self.facet_prefix, True)
+        return True
 
     def _handle_scalar(self, term, value, element,
                        type=None, serialize=False):
@@ -140,16 +144,17 @@ class Schema(schema.Form):
                     type)
             else:
                 self._add_value(value, name, type)
+        return value
 
     def _handle_string(self, element):
         value = element.value
         if value:
-            self._handle_scalar(value, value, element, 'string')
+            return self._handle_scalar(value, value, element, 'string')
 
     def _handle_integer(self, element):
         value = element.value
         if value:
-            self._handle_scalar(value, value, element, 'integer', True)
+            return self._handle_scalar(value, value, element, 'integer', True)
 
     def _handle_float(self, element):
         # TODO:mp floats are currently storage only
@@ -158,17 +163,17 @@ class Schema(schema.Form):
     def _handle_boolean(self, element):
         value = 'true' if element.value else 'false'
         if value:
-            self._handle_scalar(value, value, element, 'integer', True)
+            return self._handle_scalar(value, value, element, 'integer', True)
 
     def _handle_date(self, element):
         if element.value:
             term = element.value.strftime(element.term_format)
             value = element.value.strftime(element.value_format)
-            self._handle_scalar(term, value, element, 'date')
+            return self._handle_scalar(term, value, element, 'date')
 
     def _handle_text(self, element):
         value = element.value
-        if not value:
+        if value is None:
             return
         name = element.flattened_name()
         if element.language is _use_schema:
@@ -200,6 +205,7 @@ class Schema(schema.Form):
             index_text(value, 1, _prefix(name))
         else:
             index_text(value)
+        return value
 
     def _handle_numericrange(self, element):
         maxv = element['high'].value or 0
@@ -219,10 +225,12 @@ class Schema(schema.Form):
         for i in xrange(minv, maxv, step):
             val = "%s_%s" % (i, i + step)
             self._add_term(val, element.name, True)
+        return True
 
     def _handle_location(self, element):
         h = 'loc_' + element.hash(element.radians)
         self._add_term(h, boolean=True)
+        return True
 
     def _check_prefix(self, name, boolean=False):
         database = self.database
